0.2.32 (2024-05-12)
-------------------

Added an optional cover image to post. For podcasts the iTunes artwork will be used
as a fallback.

- #56 Added some documentation for post and related models
- #136 Added cover image to post
- #139 Fixed codecov upload
